@@ -43,17 +43,6 @@ class Customer(Model):
             return self.urlid
 
 
-class BusinessProvider(Model):
-    name = models.CharField(max_length=255, null=True, blank=True)
-    fee = models.PositiveIntegerField(default='0', null=True, blank=True)
-
-    def __str__(self):
-        try:
-            return '{} ({})'.format(self.name, self.urlid)
-        except:
-            return self.urlid
-
-
 def auto_increment_project_number():
   last_inc = Project.objects.all().order_by('id').last()
   if not last_inc:
@@ -84,7 +73,6 @@ class Project(Model):
     captain = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.SET_NULL, blank=True, null=True,
                                 related_name='+')
     driveID = models.TextField(null=True, blank=True)
-    businessProvider = models.ForeignKey(BusinessProvider, blank=True, null=True, on_delete=models.SET_NULL)
     jabberID = models.CharField(max_length=255, blank=True, null=True)
     jabberRoom = models.BooleanField(default=True)
 
@@ -107,6 +95,18 @@ class Project(Model):
         return self.members.filter(is_admin=True)
 
 
+class BusinessProvider(Model):
+    project = models.ForeignKey(Project, on_delete=models.CASCADE, related_name='businessprovider', null=True, blank=True)
+    name = models.CharField(max_length=255, null=True, blank=True)
+    fee = models.PositiveIntegerField(default='0', null=True, blank=True)
+
+    def __str__(self):
+        try:
+            return '{} ({})'.format(self.name, self.urlid)
+        except:
+            return self.urlid
+
+
 class Member(Model):
     project = models.ForeignKey(Project, on_delete=models.CASCADE, related_name='members', null=True, blank=True)
     user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name='projects', null=True, blank=True)
